==> simgrid_3.9~rc1.orig.tar.gz: SimGrid-3.9/doc/html/group__XBT__ex.js <==
var group__XBT__ex =
[
    [ "xbt_ex_t", "structxbt__ex__t.html", null ],
    [ "TRY", "group__XBT__ex.html#gad2746371528bdf15c3910b7bf217dac0", null ],
    [ "TRY_CLEANUP", "group__XBT__ex.html#ga24540d57ce6a4e72e2c2150327972fc6", null ],
    [ "CATCH", "group__XBT__ex.html#gab3271e393133e395129cc74272f9fae2", null ],
    [ "CATCH_ANONYMOUS", "group__XBT__ex.html#ga070f91546c08b1e31c1d7184c3c9b345", null ],
    [ "THROW_PREPARE", "group__XBT__ex.html#ga26394bf7f63640059e73dc55b5911a9b", null ],
    [ "THROW", "group__XBT__ex.html#gae18641b6be3a88a74eb003978399fe90", null ],
    [ "THROWF", "group__XBT__ex.html#gaf104c05a68884bf85630ef40ca8ae774", null ],
    [ "RETHROW", "group__XBT__ex.html#ga241d764fad0bff69d31c12b3066c276c", null ],
    [ "RETHROWF", "group__XBT__ex.html#ga4826ac71c1c4d2ec13eeac8320898dc9", null ],
    [ "xbt_errcat_t", "group__XBT__ex.html#gaa45fec59aa57056784554a7f998f0854", [
      [ "unknown_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a38ca7f2d055a68295cbd837470325f46", null ],
      [ "arg_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a1d6d5b33334f960325a65e5c021aca16", null ],
      [ "bound_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854ae2954a4c5a79d65f9f68675fea93376b", null ],
      [ "mismatch_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854aad84e78423b0ba9b3df634f564a38586", null ],
      [ "not_found_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a2a966e9e887d3ab79628272781200439", null ],
      [ "system_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a0cc55923f6bdf388d75ac17681055815", null ],
      [ "network_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854afa15abb01e5f46363458529588f0d871", null ],
      [ "timeout_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854acbb4310f650e6fddbbad783293eff676", null ],
      [ "cancel_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a78725e8318a373565146a9c29698eb30", null ],
      [ "thread_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a2d90a8bed8343426b9732511aa2cb34c", null ],
      [ "host_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a1486a4899ea0336633c33a77c636eea8", null ],
      [ "tracing_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a288db5d5a882653cc5466f62369ab676", null ],
      [ "io_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a7867239bb18a1f74d007fd1cc5f2202c", null ]
    ] ],
    [ "xbt_ex_catname", "group__XBT__ex.html#gad584839e617fbfe728225fc7bcfcda9f", null ],
    [ "xbt_ex_free", "group__XBT__ex.html#ga9a7c9f33be5ab51ff734142b07178553", null ],
    [ "xbt_backtrace_display_current", "group__XBT__ex.html#ga36813e215c49af92c8a62dd8286d6421", null ],
    [ "xbt_backtrace_no_malloc", "group__XBT__ex.html#gadb6f0cc90ede2c80fff99a2f3a8ea02f", null ],
    [ "xbt_backtrace_current", "group__XBT__ex.html#ga3f9f1d5af6de5e90e5501e105b0e593c", null ],
    [ "xbt_backtrace_display", "group__XBT__ex.html#gaea1e39d44bcaaebb91a34f6ef053c60c", null ]
];

==> simgrid_3.10.orig.tar.gz: SimGrid-3.10/doc/html/group__XBT__ex.js <==
var group__XBT__ex =
[
    [ "xbt_ex_t", "structxbt__ex__t.html", null ],
    [ "TRY", "group__XBT__ex.html#gad2746371528bdf15c3910b7bf217dac0", null ],
    [ "TRY_CLEANUP", "group__XBT__ex.html#ga24540d57ce6a4e72e2c2150327972fc6", null ],
    [ "CATCH", "group__XBT__ex.html#gab3271e393133e395129cc74272f9fae2", null ],
    [ "CATCH_ANONYMOUS", "group__XBT__ex.html#ga070f91546c08b1e31c1d7184c3c9b345", null ],
    [ "THROW_PREPARE", "group__XBT__ex.html#ga26394bf7f63640059e73dc55b5911a9b", null ],
    [ "THROW", "group__XBT__ex.html#gae18641b6be3a88a74eb003978399fe90", null ],
    [ "THROWF", "group__XBT__ex.html#gaf104c05a68884bf85630ef40ca8ae774", null ],
    [ "RETHROW", "group__XBT__ex.html#ga241d764fad0bff69d31c12b3066c276c", null ],
    [ "RETHROWF", "group__XBT__ex.html#ga4826ac71c1c4d2ec13eeac8320898dc9", null ],
    [ "xbt_errcat_t", "group__XBT__ex.html#gaa45fec59aa57056784554a7f998f0854", [
      [ "unknown_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a38ca7f2d055a68295cbd837470325f46", null ],
      [ "arg_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a1d6d5b33334f960325a65e5c021aca16", null ],
      [ "bound_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854ae2954a4c5a79d65f9f68675fea93376b", null ],
      [ "mismatch_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854aad84e78423b0ba9b3df634f564a38586", null ],
      [ "not_found_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a2a966e9e887d3ab79628272781200439", null ],
      [ "system_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a0cc55923f6bdf388d75ac17681055815", null ],
      [ "network_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854afa15abb01e5f46363458529588f0d871", null ],
      [ "timeout_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854acbb4310f650e6fddbbad783293eff676", null ],
      [ "cancel_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a78725e8318a373565146a9c29698eb30", null ],
      [ "thread_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a2d90a8bed8343426b9732511aa2cb34c", null ],
      [ "host_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a1486a4899ea0336633c33a77c636eea8", null ],
      [ "tracing_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a288db5d5a882653cc5466f62369ab676", null ],
      [ "io_error", "group__XBT__ex.html#ggaa45fec59aa57056784554a7f998f0854a7867239bb18a1f74d007fd1cc5f2202c", null ]
    ] ],
    [ "xbt_ex_catname", "group__XBT__ex.html#gad584839e617fbfe728225fc7bcfcda9f", null ],
    [ "xbt_ex_free", "group__XBT__ex.html#ga9a7c9f33be5ab51ff734142b07178553", null ],
    [ "xbt_backtrace_display_current", "group__XBT__ex.html#ga36813e215c49af92c8a62dd8286d6421", null ],
    [ "xbt_backtrace_no_malloc", "group__XBT__ex.html#gadb6f0cc90ede2c80fff99a2f3a8ea02f", null ],
    [ "xbt_backtrace_current", "group__XBT__ex.html#ga3f9f1d5af6de5e90e5501e105b0e593c", null ],
    [ "xbt_backtrace_display", "group__XBT__ex.html#gaea1e39d44bcaaebb91a34f6ef053c60c", null ],
    [ "xbt_libunwind_backtrace", "group__XBT__ex.html#ga6752f914268fb60019f9cf94a34ad28a", null ]
];
